@@ -17,7 +17,7 @@ use Image::ExifTool::Exif;
 use Image::ExifTool::MakerNotes;
 use Image::ExifTool::CanonRaw;
 
-$VERSION = '1.23';
+$VERSION = '1.24';
 
 sub ProcessOriginalRaw($$$);
 sub ProcessAdobeData($$$);
@@ -120,6 +120,25 @@ sub WriteAdobeStuff($$$);
     },
 );
 
+# (DNG 1.7)
+%Image::ExifTool::DNG::ImageSeq = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    0 => { Name => 'SeqID',         Format => 'var_string' },
+    1 => { Name => 'SeqType',       Format => 'var_string' },
+    2 => { Name => 'SeqFrameInfo',  Format => 'var_string' },
+    3 => { Name => 'SeqIndex',      Format => 'int32u' },
+    7 => { Name => 'SeqCount',      Format => 'int32u' },
+    11 => { Name => 'SeqFinal',     Format => 'int8u', PrintConv => { 0 => 'No', 1 => 'Yes' } },
+);
+
+# (DNG 1.7)
+%Image::ExifTool::DNG::ProfileDynamicRange = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    0 => { Name => 'PDRVersion',    Format => 'int16u' },
+    2 => { Name => 'DynamicRange',  Format => 'int16u', PrintConv => { 0 => 'Standard', 1 => 'High' } },
+    4 => { Name => 'HintMaxOutputValue', Format => 'float' },
+);
+
 # fill in maker notes
 {
     my $tagInfo;
@@ -616,7 +635,7 @@ sub ProcessAdobeIFD($$$)
 
     # parse the mutilated IFD.  This is similar to a TIFF IFD, except:
     # - data follows directly after Count entry in IFD
-    # - byte order of IFD entires is always big-endian, but byte order of data changes
+    # - byte order of IFD entries is always big-endian, but byte order of data changes
     SetByteOrder('MM');     # IFD structure is always big-endian
     my $entries = Get16u($dataPt, $pos + 2);
     $et->VerboseDir($dirInfo, $entries);
@@ -662,6 +681,7 @@ sub ProcessAdobeIFD($$$)
 # Inputs: 0) ExifTool object ref, 1) dirInfo ref, 2) tag table ref
 # Returns: 1 on success, otherwise returns 0 and sets a Warning
 # Notes: data has 6 byte header (2 for byte order and 4 for original offset)
+#        --> or 18 bytes for DNG converted from JPG by Adobe Camera Raw!
 sub ProcessAdobeMakN($$$)
 {
     my ($et, $dirInfo, $tagTablePtr) = @_;
@@ -677,8 +697,20 @@ sub ProcessAdobeMakN($$$)
 
     $et->VerboseDir($dirInfo) unless $outfile;
     my $dataPos = $$dirInfo{DataPos};
-    my $dirStart = $start + 6;  # pointer to maker note directory
-    my $dirLen = $len - 6;
+    my $hdrLen = 6;
+
+    # 2018-09-27: hack for extra 12 bytes in MakN header of JPEG converted to DNG
+    # by Adobe Camera Raw (4 bytes "00 00 00 01" followed by 8 unknown bytes)
+    # - this is because CameraRaw copies the maker notes from the wrong location
+    #   in a JPG image (off by 12 bytes presumably due to the JPEG headers)
+    # - this hack won't work in most cases because the extra bytes are not consistent
+    #   since they are just the data that existed in the JPG before the maker notes
+    # - also, the last 12 bytes of the maker notes will be missing
+    # - 2022-04-26: this bug still exists in Camera Raw 14.3
+    $hdrLen += 12 if $len >= 18 and substr($$dataPt, $start+6, 4) eq "\0\0\0\x01";
+
+    my $dirStart = $start + $hdrLen;    # pointer to maker note directory
+    my $dirLen = $len - $hdrLen;
 
     my $hdr = substr($$dataPt, $dirStart, $dirLen < 48 ? $dirLen : 48);
     my $tagInfo = $et->GetTagInfo($tagTablePtr, 'MakN', \$hdr);
@@ -707,7 +739,7 @@ sub ProcessAdobeMakN($$$)
         return 0;
     }
     if ($et->Options('HtmlDump')) {
-        $et->HDump($dataPos + $start, 6, 'Adobe MakN data');
+        $et->HDump($dataPos + $start, $hdrLen, 'Adobe MakN data');
         $et->HDump($dataPos + $dirStart, $loc, "$$tagInfo{Name} header") if $loc;
     }
 
@@ -746,8 +778,8 @@ sub ProcessAdobeMakN($$$)
         $loc = 0 if $subdirInfo{BlockWrite};
         $fixup->{Shift} += $loc;    # adjust for makernotes header
         $fixup->ApplyFixup(\$buff); # fix up pointer offsets
-        # get copy of original Adobe header (6) and makernotes header ($loc)
-        my $header = substr($$dataPt, $start, 6 + $loc);
+        # get copy of original Adobe header (6 or 18) and makernotes header ($loc)
+        my $header = substr($$dataPt, $start, $hdrLen + $loc);
         # add Adobe and makernotes headers to new directory
         $$outfile = $header . $buff;
     } else {
@@ -773,7 +805,11 @@ sub ProcessAdobeMakN($$$)
                 return 1 unless $$tagInfo{Writable};
             }
             $val = substr($$dataPt, 20) unless defined $val;
-            $et->FoundTag($tagInfo, $val);
+            my $key = $et->FoundTag($tagInfo, $val);
+            if ($$et{MAKER_NOTE_FIXUP}) {
+                $$et{TAG_EXTRA}{$key}{Fixup} = $$et{MAKER_NOTE_FIXUP};
+                delete $$et{MAKER_NOTE_FIXUP};
+            }
         }
     }
     return 1;
@@ -813,7 +849,7 @@ information in DNG (Digital Negative) images.
 
 =head1 AUTHOR
 
-Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
