@@ -16,7 +16,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.36';
+$VERSION = '1.37';
 
 sub ProcessJpeg2000Box($$$);
 sub ProcessJUMD($$$);
@@ -89,12 +89,14 @@ my %uuid = (
 # JPEG2000 codestream markers (ref ISO/IEC FCD15444-1/2)
 my %j2cMarker = (
     0x4f => 'SOC', # start of codestream
+  # 0x50 - seen in JPH codestream
     0x51 => 'SIZ', # image and tile size
     0x52 => 'COD', # coding style default
     0x53 => 'COC', # coding style component
     0x55 => 'TLM', # tile-part lengths
     0x57 => 'PLM', # packet length, main header
     0x58 => 'PLT', # packet length, tile-part header
+  # 0x59 - seen in JPH codestream
     0x5c => 'QCD', # quantization default
     0x5d => 'QCC', # quantization component
     0x5e => 'RGN', # region of interest
@@ -128,12 +130,21 @@ my %j2cMarker = (
     WRITE_PROC => \&ProcessJpeg2000Box,
     PREFERRED => 1, # always add these tags when writing
     NOTES => q{
-        The tags below are found in JPEG 2000 images and the JUMBF metadata in JPEG
-        images, but not all of these are extracted.  Note that ExifTool currently
-        writes only EXIF, IPTC and XMP tags in Jpeg2000 images, and EXIF and XMP in
-        JXL images.  ExifTool will read/write Brotli-compressed EXIF and XMP in JXL
-        images, but the API L<Compress|../ExifTool.html#Compress> option must be set to create new EXIF and XMP
-        in compressed format.
+        The tags below are found in JPEG 2000 images and the C2PA CAI JUMBF metadata
+        in various file types (see below).  Note that ExifTool currently writes only
+        EXIF, IPTC and XMP tags in Jpeg2000 images, and EXIF and XMP in JXL images. 
+        ExifTool will read/write Brotli-compressed EXIF and XMP in JXL images, but
+        the API L<Compress|../ExifTool.html#Compress> option must be set to create new EXIF and XMP in compressed
+        format.
+
+        C2PA (Coalition for Content Provenance and Authenticity) CAI (Content
+        Authenticity Initiative) JUMBF (JPEG Universal Metadata Box Format) metdata
+        is currently extracted from JPEG, PNG, TIFF-based (eg. TIFF, DNG),
+        QuickTime-based (eg. MP4, MOV, HEIF, AVIF), RIFF-based (eg. WAV, AVI, WebP),
+        GIF files and ID3v2 metadata.  The suggested ExifTool command-line arguments
+        for reading C2PA metadata are C<-jumbf:all -G3 -b -j -u -struct>.  This
+        metadata may be deleted from writable JPEG, PNG, WebP, TIFF-based, and
+        QuickTime-based files by deleting the JUMBF group with C<-jumbf:all=>.
     },
 #
 # NOTE: ONLY TAGS WITH "Format" DEFINED ARE EXTRACTED!
@@ -345,13 +356,6 @@ my %j2cMarker = (
                 Start => '$valuePtr + 16',
             },
         },
-        {
-            Name => 'UUID-Signature',  # (seen in JUMB data of JPEG images)
-            # (may be able to remove this when JUMBF specification is finalized)
-            Condition => '$$valPt=~/^casg\x00\x11\x00\x10\x80\x00\x00\xaa\x00\x38\x9b\x71/',
-            Format => 'undef',
-            ValueConv => 'substr($val,16)',
-        },
         {
             Name => 'UUID-C2PAClaimSignature',  # (seen in incorrectly-formatted JUMB data of JPEG images)
             # (may be able to remove this when JUMBF specification is finalized)
@@ -361,6 +365,13 @@ my %j2cMarker = (
                 Start => '$valuePtr + 16',
             },
         },
+        {
+            Name => 'UUID-Signature',  # (seen in JUMB data of JPEG images)
+            # (may be able to remove this when JUMBF specification is finalized)
+            Condition => '$$valPt=~/^casg\x00\x11\x00\x10\x80\x00\x00\xaa\x00\x38\x9b\x71/',
+            Format => 'undef',
+            ValueConv => 'substr($val,16)',
+        },
         {
             Name => 'UUID-Unknown',
         },
@@ -549,6 +560,7 @@ my %j2cMarker = (
             'jpm ' => 'JPEG 2000 Compound Image (.JPM)',  # image/jpm
             'jpx ' => 'JPEG 2000 with extensions (.JPX)', # image/jpx
             'jxl ' => 'JPEG XL Image (.JXL)',             # image/jxl
+            'jph ' => 'High-throughput JPEG 2000 (.JPH)', # image/jph
         },
     },
     1 => {
@@ -842,6 +854,17 @@ sub ProcessJUMD($$$)
     return 1;
 }
 
+#------------------------------------------------------------------------------
+# Warn about error in Brotli compression/decompression
+# Inputs: 0) ExifTool ref, 1) box type, 2) true for decoding (Uncompress)
+sub BrotliWarn($$;$)
+{
+    my ($et, $type, $uncompress) = @_;
+    my ($enc, $mod) = $uncompress ? qw(decoding Uncompress) : qw(encoding Compress);
+    $et->WarnOnce("Error $enc '${type}' brob box");
+    $et->WarnOnce("Try updating to IO::${mod}::Brotli 0.004 or later");
+}
+
 #------------------------------------------------------------------------------
 # Create new JPEG 2000 boxes when writing
 # (Currently only supports adding top-level Writable JPEG2000 tags and certain UUID boxes)
@@ -897,7 +920,7 @@ sub CreateNewBoxes($$)
                         my $compressed;
                         eval { $compressed = IO::Compress::Brotli::bro($pad . $newdir) };
                         if ($@ or not $compressed) {
-                            $et->Warn("Error encoding $dirName brob box");
+                            BrotliWarn($et, $dirName);
                         } else {
                             $et->VPrint(0, "  Writing Brotli-compressed $dir\n");
                             $newdir = $compressed;
@@ -993,10 +1016,12 @@ sub ProcessJpeg2000Box($$$)
     my $dirLen = $$dirInfo{DirLen} || 0;
     my $dirStart = $$dirInfo{DirStart} || 0;
     my $base = $$dirInfo{Base} || 0;
-    my $raf = $$dirInfo{RAF};
     my $outfile = $$dirInfo{OutFile};
     my $dirEnd = $dirStart + $dirLen;
-    my ($err, $outBuff, $verbose, $doColour, $hash);
+    my ($err, $outBuff, $verbose, $doColour, $hash, $raf);
+
+    # read from RAF unless reading from buffer
+    $raf = $$dirInfo{RAF} unless $dataPt;
 
     if ($outfile) {
         unless ($raf) {
@@ -1234,7 +1259,7 @@ sub ProcessJpeg2000Box($$$)
                                 my $compressed;
                                 eval { $compressed = IO::Compress::Brotli::bro($pad . $newdir) };
                                 if ($@ or not $compressed) {
-                                    $et->Warn("Error encoding $boxID brob box");
+                                    BrotliWarn($et, $boxID);
                                 } else {
                                     $et->VPrint(0, "  Writing Brotli-compressed $boxID\n");
                                     $newdir = $boxID . $compressed;
@@ -1375,7 +1400,7 @@ sub ProcessBrotli($$$)
         my $verbose = $isWriting ? 0 : $et->Options('Verbose');
         my $dat = substr($$dataPt, 4);
         eval { $dat = IO::Uncompress::Brotli::unbro($dat, 100000000) };
-        $@ and $et->Warn("Error decoding $type brob box"), return 1;
+        $@ and BrotliWarn($et, $type, 1), return 1;
         $verbose > 2 and $et->VerboseDump(\$dat, Prefix => $$et{INDENT} . '  ');
         my %dirInfo = ( DataPt => \$dat );
         if ($type eq 'xml ') {
@@ -1408,7 +1433,7 @@ sub ProcessBrotli($$$)
             # rewrite as uncompressed if Compress option is set to 0 (or '')
             return $dat if defined $compress and not $compress;
             eval { $dat = IO::Compress::Brotli::bro($dat) };
-            $@ and $et->Warn("Error encoding $type brob box"), return undef;
+            $@ and BrotliWarn($et, $type), return undef;
             $et->VPrint(0, "  Writing Brotli-compressed $type\n");
             return $type . $dat;
         }
@@ -1516,6 +1541,7 @@ sub ProcessJP2($$)
             $fileType = 'JPX' if $1 eq 'jpx ';
             $fileType = 'JPM' if $1 eq 'jpm ';
             $fileType = 'JXL' if $1 eq 'jxl ';
+            $fileType = 'JPH' if $1 eq 'jph ';
         }
         $raf->Seek(-length($buff), 1) if defined $buff;
         $et->SetFileType($fileType);
@@ -1605,7 +1631,7 @@ files.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
