@@ -21,7 +21,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.26';
+$VERSION = '1.28';
 
 sub ProcessJpgFromRaw($$$);
 sub WriteJpgFromRaw($$$);
@@ -266,6 +266,7 @@ my %panasonicWhiteBalance = ( #forum9396
         PanasonicHack => 1,
         OffsetPair => 0x117, # (use StripByteCounts as the offset pair)
         NotRealPair => 1,    # (to avoid Validate warning)
+        IsImageData => 1,
     },
     0x119 => {
         Name => 'DistortionInfo',
@@ -296,6 +297,20 @@ my %panasonicWhiteBalance = ( #forum9396
         },
     },
     # 0x122 - int32u: RAWDataOffset for the GH5s/GX9, or pointer to end of raw data for G9 (forum9295)
+    0x127 => { #github193 (newer models)
+        Name => 'JpgFromRaw2',
+        Groups => { 2 => 'Preview' },
+        DataTag => 'JpgFromRaw2',
+        RawConv => '$self->ValidateImage(\$val,$tag)',
+    },
+    0x13b => {
+        Name => 'Artist',
+        Groups => { 2 => 'Author' },
+        Permanent => 1, # (so we don't add it if the model doesn't write it)
+        Writable => 'string',
+        WriteGroup => 'IFD0',
+        RawConv => '$val =~ s/\s+$//; $val', # trim trailing blanks
+    },
     0x2bc => { # PH Extension!!
         Name => 'ApplicationNotes', # (writable directory!)
         Writable => 'int8u',
@@ -318,6 +333,17 @@ my %panasonicWhiteBalance = ( #forum9396
             noise-reduction strengths the R, G and B channels
         },
     },
+    0x8298 => { #github193
+        Name => 'Copyright',
+        Groups => { 2 => 'Author' },
+        Permanent => 1, # (so we don't add it if the model doesn't write it)
+        Format => 'undef',
+        Writable => 'string',
+        WriteGroup => 'IFD0',
+        RawConv => $Image::ExifTool::Exif::Main{0x8298}{RawConv},
+        RawConvInv => $Image::ExifTool::Exif::Main{0x8298}{RawConvInv},
+        PrintConvInv => $Image::ExifTool::Exif::Main{0x8298}{PrintConvInv},
+    },
     0x83bb => { # PH Extension!!
         Name => 'IPTC-NAA', # (writable directory!)
         Format => 'undef',      # convert binary values as undef
@@ -739,6 +765,7 @@ sub WriteDistortionInfo($$$)
 #  3 - reference to list of original offset values
 #  4 - IFD format number
 #  5 - (pointer to StripOffsets value added by this PatchRawDataOffset routine)
+#  6 - flag set if this is a fixed offset (Panasonic GH6 fixed-offset hack)
 sub PatchRawDataOffset($$$)
 {
     my ($offsetInfo, $raf, $ifd) = @_;
@@ -752,10 +779,16 @@ sub PatchRawDataOffset($$$)
     } else {
         # the DC-GH6 and DC-GH5M2 write RawDataOffset with no Strip tags, so we need
         # to create fake StripByteCounts information for copying the data
-      # (disable this until SilkyPix and Adobe utilities can deal with a variable
-      #  RawDataOffset, see https://exiftool.org/forum/index.php?topic=13861.0 --
-      #  so these files will continue to give a "No size tag" error when writing)
-      #  $stripByteCounts = $$offsetInfo{0x117} = [ $PanasonicRaw::Main{0x117}, 0, 1, [ 0 ], 4 ];
+        if ($$offsetInfo{0x118}) { # (just to be safe)
+            $stripByteCounts = $$offsetInfo{0x117} = [ $PanasonicRaw::Main{0x117}, 0, 1, [ 0 ], 4 ];
+            # set flag so the offset will be fixed (GH6 hack, see https://exiftool.org/forum/index.php?topic=13861.0)
+            # (of course, fixing up the offset is now unnecessary, but continue to do this even
+            # though the fixup adjustment will be 0 because this allows us to delete the following
+            # line to remove the fix-offset restriction if Panasonic ever sees the light, but note
+            # that in this case we should investigate the purpose of the seemily-duplicate raw
+            # data offset contained within PanasonicRaw_0x0044)
+            $$offsetInfo{0x118}[6] = 1;
+        }
     }
     if ($rawDataOffset and not $err) {
         $err = 1 unless $$rawDataOffset[2] == 1;
@@ -901,7 +934,7 @@ write meta information in Panasonic/Leica RAW, RW2 and RWL images.
 
 =head1 AUTHOR
 
-Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
